Stan Math Library: Member List

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::sum_eigen_v_vari Member List

This is the complete list of members for stan::math::sum_eigen_v_vari, including all inherited members.

adj_ | stan::math::vari |
chain() | stan::math::sum_v_vari | inlinevirtual
init_dependent() | stan::math::vari | inline
length_ | stan::math::sum_v_vari | protected
operator delete(void *) | stan::math::vari | inlinestatic
operator new(size_t nbytes) | stan::math::vari | inlinestatic
set_zero_adjoint() | stan::math::vari | inline
sum_eigen_v_vari(const Eigen::Matrix< var, R1, C1 > &v1) | stan::math::sum_eigen_v_vari | inlineexplicit
sum_of_val(const Eigen::DenseBase< Derived > &v) | stan::math::sum_eigen_v_vari | inlineprotectedstatic
stan::math::sum_v_vari::sum_of_val(const std::vector< var > &v) | stan::math::sum_v_vari | inlineprotectedstatic
sum_v_vari(double value, vari **v, size_t length) | stan::math::sum_v_vari | inlineexplicit
sum_v_vari(const std::vector< var > &v1) | stan::math::sum_v_vari | inlineexplicit
v_ | stan::math::sum_v_vari | protected
val_ | stan::math::vari |
vari(const double x) | stan::math::vari | inlineexplicit
vari(const double x, bool stacked) | stan::math::vari | inline
~vari() | stan::math::vari | inlinevirtual

[ Stan Home Page ] © 2011–2016, Stan Development Team.